==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/EventLogProcessFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link EventLogProcess}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class EventLogProcessFieldAttributes extends AbstractBeanAttributesDefinition{

    /** configId (Database column: CONFIG_ID) */
    static public AttributeDefinition configId =
        new AttributeDefinition("configId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("CONFIG_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** dateEventProcess (Database column: DATE_EVENT_PROCESS) */
    static public AttributeDefinition dateEventProcess =
        new AttributeDefinition("dateEventProcess")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("DATE_EVENT_PROCESS")
                .setMandatory(true)
                .setMaxSize(7)
                .setType(Timestamp.class);

    /** event (Database column: EVENT_ID) */
    static public AttributeDefinition event =
        new AttributeDefinition("event")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("EVENT_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Event.class);

    /** eventSubscription (Database column: EVENT_SUBSCRIPTION_ID) */
    static public AttributeDefinition eventSubscription =
        new AttributeDefinition("eventSubscription")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("EVENT_SUBSCRIPTION_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.EventSubscription.class);

    /** externalId (Database column: EXTERNAL_ID) */
    static public AttributeDefinition externalId =
        new AttributeDefinition("externalId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("EXTERNAL_ID")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** result (Database column: RESULT) */
    static public AttributeDefinition result =
        new AttributeDefinition("result")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("RESULT")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** state (Database column: STATE) */
    static public AttributeDefinition state =
        new AttributeDefinition("state")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("STATE")
                .setMandatory(true)
                .setMaxSize(1)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(configId.getName(),configId);
        map.put(dateEventProcess.getName(),dateEventProcess);
        map.put(event.getName(),event);
        map.put(eventSubscription.getName(),eventSubscription);
        map.put(externalId.getName(),externalId);
        map.put(id.getName(),id);
        map.put(result.getName(),result);
        map.put(state.getName(),state);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/EventLogProcessFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link EventLogProcess}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class EventLogProcessFieldAttributes extends AbstractBeanAttributesDefinition{

    /** configId (Database column: CONFIG_ID) */
    static public AttributeDefinition configId =
        new AttributeDefinition("configId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("CONFIG_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** dateEventProcess (Database column: DATE_EVENT_PROCESS) */
    static public AttributeDefinition dateEventProcess =
        new AttributeDefinition("dateEventProcess")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("DATE_EVENT_PROCESS")
                .setMandatory(true)
                .setMaxSize(7)
                .setType(Timestamp.class);

    /** event (Database column: EVENT_ID) */
    static public AttributeDefinition event =
        new AttributeDefinition("event")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("EVENT_ID")
                .setMandatory(false)
                .setMaxSize(10)
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Event.class);

    /** eventSubscription (Database column: EVENT_SUBSCRIPTION_ID) */
    static public AttributeDefinition eventSubscription =
        new AttributeDefinition("eventSubscription")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("EVENT_SUBSCRIPTION_ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.EventSubscription.class);

    /** externalId (Database column: EXTERNAL_ID) */
    static public AttributeDefinition externalId =
        new AttributeDefinition("externalId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("EXTERNAL_ID")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** result (Database column: RESULT) */
    static public AttributeDefinition result =
        new AttributeDefinition("result")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("RESULT")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** state (Database column: STATE) */
    static public AttributeDefinition state =
        new AttributeDefinition("state")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_LOG_PROCESS")
                .setDatabaseId("STATE")
                .setMandatory(true)
                .setMaxSize(1)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(configId.getName(),configId);
        map.put(dateEventProcess.getName(),dateEventProcess);
        map.put(event.getName(),event);
        map.put(eventSubscription.getName(),eventSubscription);
        map.put(externalId.getName(),externalId);
        map.put(id.getName(),id);
        map.put(result.getName(),result);
        map.put(state.getName(),state);

        return map;
    }
}
